@@ -1,7 +1,7 @@
 """tracker extproject and project entity classes
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -14,15 +14,11 @@ from cubicweb.selectors import is_instance
 from cubicweb.entities import AnyEntity, fetch_config
 from cubicweb.entities.adapters import ITreeAdapter
 
-from cubes.tracker.entities import fixed_orderby_rql, attr_tuple
-
 class Project(AnyEntity):
     __regid__ = 'Project'
     __permissions__ = ('developer', 'client')
-    fetch_attrs, fetch_order = fetch_config(('name', 'description', 'description_format',
-                                             'summary'))
-
-    TICKET_DEFAULT_STATE_RESTR = 'S name IN ("created","identified","released","scheduled")'
+    fetch_attrs, cw_fetch_order = fetch_config(('name', 'description', 'description_format',
+                                                'summary'))
 
     def dc_title(self):
         return self.name
@@ -72,28 +68,6 @@ class Project(AnyEntity):
               'V version_of P, P eid %%(p)s' % (order, ','.join(repr(s) for s in states))
         return self._cw.execute(rql, {'p': self.eid})
 
-    # number of columns to display
-    tickets_rql_nb_displayed_cols = 7
-    sort_defs = (('in_state', 'S'), ('num', 'VN'), ('priority', 'PR'))
-    def tickets_rql(self, limit=None):
-        return ('Any B, NOW - CD, NOW - BMD, U,PR,S,V,BD,VN,P,BT,CD,BMD,UL '
-                'GROUPBY B,CD,PR,S,V,U,VN,BD,P,BT,BMD,UL '
-                '%s %s '
-                'WHERE B priority PR, B in_state S, B creation_date CD, '
-                'B description BD, '
-                'B title BT, B modification_date BMD, '
-                'B done_in V?, V num VN, '
-                'B created_by U?, U login UL, B concerns P, P eid %%(x)s'
-                % (fixed_orderby_rql(self.sort_defs),
-                   limit and ' LIMIT %r' % limit or ''),
-                {'x': self.eid})
-
-    def active_tickets_rql(self):
-        rql = self.tickets_rql()
-        if isinstance(rql, tuple):
-            rql = rql[0] % rql[1]
-        return '%s, %s' % (rql, self.TICKET_DEFAULT_STATE_RESTR)
-
 
 class ProjectITreeAdapter(ITreeAdapter):
     __select__ = is_instance('Project')
