@@ -1,22 +1,22 @@
 """tracker version entity class
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 
-from datetime import date
-
 from logilab.common.decorators import cached
 from logilab.common.date import todate
 
+from rql import nodes
+
 from cubicweb import ValidationError
 from cubicweb.entities import AnyEntity
-from cubicweb.entities.adapters import IProgressAdapter, IUserFriendlyUniqueTogether
-from cubicweb.selectors import is_instance, match_exception
+from cubicweb.entities.adapters import IUserFriendlyUniqueTogether
+from cubicweb.selectors import is_instance
 
-from cubes.tracker.entities import fixed_orderby_rql
+from cubes.iprogress.entities import IProgressAdapter
 
 
 class VersionIProgressAdapter(IProgressAdapter):
@@ -74,12 +74,14 @@ class Version(AnyEntity):
     PUBLISHED_STATES = (u'published',)
 
     @classmethod
-    def fetch_order(cls, attr, var):
+    def cw_fetch_order(cls, select, attr, var):
         if attr == 'num':
-            var = 'version_sort_value(%s)' % var
-            return '%s DESC' % var
-        return None
-    fetch_unrelated_order = fetch_order
+            func = nodes.Function('version_sort_value')
+            func.append(nodes.variable_ref(var))
+            sterm = nodes.SortTerm(func, asc=False)
+            select.add_sort_term(sterm)
+
+    cw_fetch_unrelated_order = cw_fetch_order
 
     def rest_path(self, use_ext_eid=False):
         return u'%s/%s' % (self.project.rest_path(), self.num)
@@ -135,43 +137,15 @@ class Version(AnyEntity):
     def open_tickets(self):
         return (ticket for ticket in self.reverse_done_in if ticket.is_open())
 
-    sort_defs = (('in_state', 'S'), ('priority', 'PR'))
-
-    tickets_rql_nb_displayed_cols = 8 # number of columns to display
-    def tickets_rql(self):
-        return ('Any B,PR,S,U,TI,D,V '
-                'GROUPBY B,PR,S,U,TI,D,V %s '
-                'WHERE B priority PR, '
-                'B in_state S, B created_by U?,'
-                'B done_in V, V eid %%(x)s, '
-                'B title TI, B description D'
-                % fixed_orderby_rql(self.sort_defs), {'x': self.eid})
-
-    defects_rql_nb_displayed_cols = 5 # number of columns to display
-    def defects_rql(self):
-        return ('Any B,PR,S,U,TI,D,V '
-                'GROUPBY B,PR,S,U,TI,D,V %s '
-                'WHERE B priority PR, '
-                'B in_state S, B created_by U?,'
-                'B appeared_in V, V eid %%(x)s, '
-                'B title TI, B description D'
-                % fixed_orderby_rql(self.sort_defs), {'x': self.eid})
-
     def sortvalue(self, rtype=None):
         if rtype is None or rtype == 'num':
-            # small hack to add the project name in the sorted values so that
-            # out-of-context views get sorted according to project names and
-            # in-context views according to version number
-            if rtype is None:
-                value = [self.project.name]
-            else:
-                value = []
-            for part in self.num.split('.'):
+            values = []
+            for i, part in enumerate(reversed(self.num.split('.'))):
                 try:
-                    value.append(int(part))
+                    values.append(int(part) * (i * 100))
                 except ValueError:
-                    value.append(part)
-            return value
+                    values.append(sum(ord(c) * (i * 100) for c in part[:2]))
+            return sum(values)
         return super(Version, self).sortvalue(rtype)
 
     @cached
