@@ -6,11 +6,6 @@
 """
 __docformat__ = "restructuredtext en"
 
-from itertools import chain
-
-from logilab.common.decorators import classproperty
-from logilab.common.compat import any
-
 from cubicweb import ValidationError
 from cubicweb.utils import transitive_closure_of
 from cubicweb.schema import META_RTYPES
@@ -18,6 +13,8 @@ from cubicweb.selectors import is_instance
 from cubicweb.server import hook
 from cubicweb.hooks import notification
 
+from cubes.localperms import hooks as localperms
+
 # automatization hooks #########################################################
 
 class VersionStatusChangeHook(hook.Hook):
@@ -144,91 +141,16 @@ class BeforeInVersionChangeHook(hook.Hook):
 
 # require_permission propagation hooks #########################################
 
-# relations where the "main" entity is the subject
-S_RELS = set()
-# relations where the "main" entity is the object
-O_RELS = set(('concerns', 'version_of', 'subproject_of'))
+# bw compat
+S_RELS = localperms.S_RELS
+O_RELS = localperms.O_RELS
+SKIP_S_RELS = localperms.SKIP_S_RELS
+SKIP_O_RELS = localperms.SKIP_O_RELS
+
 # not necessary on:
 #
 # * "secondary" relations: todo_by, done_in, appeared_in, depends_on, uses
 # * no propagation needed: wf_info_for
 #
 # XXX: see_also
-
-# relations where the "main" entity is the subject/object that should be skipped
-# when propagating to entities linked through some particular relation
-SKIP_S_RELS = set()
-SKIP_O_RELS = set()
-
-
-class AddEntitySecurityPropagationHook(hook.PropagateRelationHook):
-    """propagate permissions when new entity are added"""
-    __regid__ = 'add_entity_security_propagation'
-    __select__ = (hook.PropagateRelationHook.__select__
-                  & hook.match_rtype_sets(S_RELS, O_RELS))
-    main_rtype = 'require_permission'
-    subject_relations = S_RELS
-    object_relations = O_RELS
-
-
-class AddPermissionSecurityPropagationHook(hook.PropagateRelationAddHook):
-    __regid__ = 'add_permission_security_propagation'
-    __select__ = (hook.PropagateRelationAddHook.__select__
-                  & hook.match_rtype('require_permission'))
-    subject_relations = S_RELS
-    object_relations = O_RELS
-    skip_subject_relations = SKIP_S_RELS
-    skip_object_relations = SKIP_O_RELS
-
-class DelPermissionSecurityPropagationHook(hook.PropagateRelationDelHook):
-    __regid__ = 'del_permission_security_propagation'
-    __select__ = (hook.PropagateRelationDelHook.__select__
-                  & hook.match_rtype('require_permission'))
-    subject_relations = S_RELS
-    object_relations = O_RELS
-    skip_subject_relations = SKIP_S_RELS
-    skip_object_relations = SKIP_O_RELS
-
-
-# has_group_permission propagation hooks #######################################
-
-class AddGroupPermissionSecurityPropagationHook(hook.Hook):
-    """propagate on group users when a permission is granted to a group"""
-    __regid__ = 'add_group_permission_security_propagation'
-    __select__ = hook.Hook.__select__ & hook.match_rtype('require_group',)
-    events = ('after_add_relation',)
-    rql = ('SET U has_group_permission P WHERE U in_group G, P eid %(p)s, G eid %(g)s,'
-           'NOT U has_group_permission P')
-
-    def __call__(self):
-        if self._cw.describe(self.eidfrom)[0] != 'CWPermission':
-            return
-        self._cw.execute(self.rql, {'p': self.eidfrom, 'g': self.eidto})
-
-
-class DelGroupPermissionSecurityPropagationHook(AddGroupPermissionSecurityPropagationHook):
-    """propagate on group users when a permission is removed to a group"""
-    __regid__ = 'del_group_permission_security_propagation'
-    events = ('after_delete_relation',)
-    rql = ('DELETE U has_group_permission P WHERE U in_group G, P eid %(p)s, G eid %(g)s,'
-           'NOT EXISTS(U in_group G2, P require_group G2)')
-
-
-class AddInGroupSecurityPropagationHook(hook.Hook):
-    """propagate group permission to users when a permission is granted to a group"""
-    __regid__ = 'add_in_group_permission_security_propagation'
-    __select__ = hook.Hook.__select__ & hook.match_rtype('in_group',)
-    events = ('after_add_relation',)
-    rql = ('SET U has_group_permission P WHERE U eid %(u)s, P require_group G, '
-           'G eid %(g)s, NOT U has_group_permission P')
-
-    def __call__(self):
-        self._cw.execute(self.rql, {'u': self.eidfrom, 'g': self.eidto})
-
-
-class DelInGroupSecurityPropagationHook(AddInGroupSecurityPropagationHook):
-    """propagate on existing entities when a permission is deleted"""
-    __regid__ = 'del_in_group_permission_security_propagation'
-    events = ('after_delete_relation',)
-    rql = ('DELETE U has_group_permission P WHERE U eid %(u)s, P require_group G, '
-           'G eid %(g)s, NOT EXISTS(U in_group G2, P require_group G2)')
+O_RELS |= set(('concerns', 'version_of', 'subproject_of'))
