@@ -24,16 +24,16 @@ except ImportError: # no server installation
 else:
 
     def init_sqlite_connexion(cnx):
-        def priority_sort_value(text):
+        def _priority_sort_value(text):
             return {"minor": "2", "normal": "1", "important":  "0"}[text]
-        cnx.create_function("PRIORITY_SORT_VALUE", 1, priority_sort_value)
+        cnx.create_function("PRIORITY_SORT_VALUE", 1, _priority_sort_value)
 
-        def version_sort_value(text):
+        def _version_sort_value(text):
             try:
                 return sum((10000, 100, 1)[i]*int(v) for i, v in enumerate(text.split(".")))
             except (ValueError, IndexError, AttributeError):
                 return 0
-        cnx.create_function("VERSION_SORT_VALUE", 1, version_sort_value)
+        cnx.create_function("VERSION_SORT_VALUE", 1, _version_sort_value)
 
     sqlite_hooks = SQL_CONNECT_HOOKS.setdefault('sqlite', [])
     sqlite_hooks.append(init_sqlite_connexion)
