@@ -103,6 +103,12 @@ class SecurityTC(TrackerTCMixIn, CubicWebTC):
             self.__cnxs[user] = self.login(user, autoclose=False, **kwargs)
         return self.__cnxs[user]
 
+    def restore_connection(self):
+        # overridden so current connection isn't closed, which is unexpected
+        # with `mylogin`
+        cnx, self.websession = self._orig_cnx
+        self.set_cnx(cnx)
+
     def _test_tr_fail(self, user, x, trname):
         cnx = self.mylogin(user)
         try:
