@@ -23,37 +23,47 @@ _afs.tag_object_of(('Version', 'version_of', 'Project'), 'main', 'hidden')
 _afs.tag_subject_of(('Ticket', 'concerns', 'Project'), 'main', 'attributes')
 _afs.tag_object_of(('Ticket', 'concerns', 'Project'), 'main', 'hidden')
 _afs.tag_subject_of(('Ticket', 'done_in', 'Version'), 'main', 'attributes')
+_afs.tag_subject_of(('Ticket', 'appeared_in', '*'), 'main', 'attributes')
+
+
+def ticket_subj_rel_choices(rtype, version_state_restr):
+    def _ticket_subj_rel_choices(form, field, rtype=rtype):
+        entity = form.edited_entity
+        # first see if its specified by __linkto form parameters
+        linkedto = field.relvoc_linkedto(form)
+        if linkedto:
+            return linkedto
+        # it isn't, check if the entity provides a method to get correct values
+        vocab = field.relvoc_init(form)
+        if not entity.has_eid():
+            peids = form.linked_to['concerns', 'subject']
+            peid = peids and peids[0]
+            veid = None
+        else:
+            peid = entity.project.eid
+            values = getattr(entity, rtype)
+            veid = values and values[0].eid
+        if peid:
+            rschema = form._cw.vreg.schema[rtype].rdef('Ticket', 'Version')
+            rset = form._cw.execute(
+                'Any V, VN, P ORDERBY version_sort_value(VN) '
+                'WHERE V version_of P, P eid %%(p)s, V num VN, '
+                'V in_state ST, %s' % version_state_restr, {'p': peid})
+            vocab += [(v.view('combobox'), unicode(v.eid)) for v in rset.entities()
+                      if rschema.has_perm(form._cw, 'add', toeid=v.eid)
+                      and not v.eid == veid]
+        return vocab
+    return _ticket_subj_rel_choices
 
-def ticket_done_in_choices(form, field):
-    entity = form.edited_entity
-    # first see if its specified by __linkto form parameters
-    linkedto = formfields.relvoc_linkedto(entity, 'done_in', 'subject')
-    if linkedto:
-        return linkedto
-    # it isn't, check if the entity provides a method to get correct values
-    vocab = formfields.relvoc_init(entity, 'done_in', 'subject')
-    if not entity.has_eid():
-        peids = entity.linked_to('concerns', 'subject')
-        peid = peids and peids[0]
-        veid = None
-    else:
-        peid = entity.project.eid
-        veid = entity.done_in and entity.done_in[0].eid
-    if peid:
-        rschema = form._cw.vreg.schema['done_in'].rdef('Ticket', 'Version')
-        rset = form._cw.execute(
-            'Any V, VN, P ORDERBY version_sort_value(VN) '
-            'WHERE V version_of P, P eid %(p)s, V num VN, '
-            'V in_state ST, NOT ST name "published"', {'p': peid})
-        vocab += [(v.view('combobox'), unicode(v.eid)) for v in rset.entities()
-                  if rschema.has_perm(form._cw, 'add', toeid=v.eid)
-                  and not v.eid == veid]
-    return vocab
 
 _affk = uicfg.autoform_field_kwargs
 _affk.tag_attribute(('Ticket', 'priority'), {'sort': False})
+ticket_done_in_choices = ticket_subj_rel_choices('done_in', 'NOT ST name "published"')
 _affk.tag_subject_of(('Ticket', 'done_in', '*'), {'sort': False,
                                                   'choices': ticket_done_in_choices})
+ticket_appeared_in_choices = ticket_subj_rel_choices('appeared_in', 'ST name "published"')
+_affk.tag_subject_of(('Ticket', 'appeared_in', '*'), {'sort': False,
+                                                  'choices': ticket_appeared_in_choices})
 
 
 class VersionChangeStateForm(workflow.ChangeStateForm):
