@@ -7,18 +7,20 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
+from datetime import datetime
+
 from logilab.mtconverter import xml_escape
 from logilab.common import table as _table
 
-from cubicweb.schema import display_name
 from cubicweb.view import EntityView, EntityStartupView
 from cubicweb.selectors import (is_instance, has_related_entities, none_rset,
-                                anonymous_user, authenticated_user, score_entity)
+                                anonymous_user, authenticated_user,
+                                score_entity, paginated_rset)
 from cubicweb import tags
 from cubicweb.web import component, uicfg
-from cubicweb.web.views import tabs, baseviews
+from cubicweb.web.views import tabs, baseviews, tableview, navigation
 
-from cubes.tracker.entities import attr_tuple
+from cubes.tracker.views import fixed_orderby_rql
 
 _pvdc = uicfg.primaryview_display_ctrl
 _pvdc.tag_attribute(('Project', 'summary'), {'showlabel': False})
@@ -29,7 +31,8 @@ _pvdc.tag_attribute(('Project', 'description'), {'showlabel': False})
 class ProjectPrimaryView(tabs.TabbedPrimaryView):
     __select__ = is_instance('Project')
 
-    tabs = [_('projectinfo_tab'), _('projectroadmap_tab'), _('projecttickets_tab')]
+    tabs = [_('projectinfo_tab'), _('projectroadmap_tab'), _('projecttickets_tab'),
+            'activitystream']
     default_tab = 'projectinfo_tab'
 
 
@@ -69,17 +72,83 @@ class ProjectTicketsTab(EntityView):
 
     title = None # should not appear in possible views
 
-    def cell_call(self, row, col):
-        entity = self.cw_rset.get_entity(row, col)
-        # optimization: prefetch project's to fill entity / relations cache
-        entity.reverse_version_of
-        # use limit=2 so filter form is selectable
-        rset = self._cw.execute(*attr_tuple(entity, 'tickets_rql', limit=2))
-        self._cw.form['actualrql'] = entity.active_tickets_rql()
-        self.wview('editable-initialtable', rset, 'null',
-                   subvid='incontext', displayactions=1,
-                   divid='tickets%s' % entity.eid,
-                   displaycols=range(entity.tickets_rql_nb_displayed_cols))
+    def entity_call(self, entity):
+        display_all = int(self._cw.form.get('display_all', 0))
+        divid = self.__regid__ + unicode(entity.eid)
+        url = self._cw.ajax_replace_url(divid, eid=entity.eid,
+                                        vid=self.__regid__,
+                                        display_all=int(not display_all))
+        if display_all:
+            rql = self.tickets_rql()
+            msg = u'<a href="%%s">%s</a>.' % self._cw._('Show only active tickets')
+        else:
+            rql = self.active_tickets_rql()
+            msg = self._cw._('Only active tickets are displayed. '
+                             '<a href="%s">Show all tickets</a>.')
+        self.w(u'<div id="%s">' % divid)
+        self.w(msg % xml_escape(url))
+        rset = self._cw.execute(rql, {'x': entity.eid})
+        self.wview('tracker.tickets.table', rset, 'null')
+        self.w(u'</div>')
+
+
+    SORT_DEFS = (('in_state', 'S'), ('num', 'VN'), ('type', 'TT'), ('priority', 'TP'))
+    TICKET_DEFAULT_STATE_RESTR = 'S name IN ("created","identified","released","scheduled")'
+
+    def tickets_rql(self):
+        # prefetch everything we can for optimization
+        return ('Any T,TTI,TT,TP,TD,TDF,TCD,TMD,S,SN,V,VN,U,UL %s WHERE '
+                'T title TTI, T type TT, T priority TP, '
+                'T description TD, T description_format TDF, '
+                'T creation_date TCD, T modification_date TMD, '
+                'T in_state S, S name SN, '
+                'T done_in V?, V num VN, '
+                'T created_by U?, U login UL, '
+                'T concerns P, P eid %%(x)s'
+                % fixed_orderby_rql(self.SORT_DEFS))
+
+    def active_tickets_rql(self):
+        return self.tickets_rql() + ', ' + self.TICKET_DEFAULT_STATE_RESTR
+
+
+class TicketsNavigation(navigation.SortedNavigation):
+    __select__ = (navigation.SortedNavigation.__select__
+                  & ~paginated_rset(4) & is_instance('Ticket'))
+    def sort_on(self):
+        col, attrname = super(TicketsNavigation, self).sort_on()
+        if col == 6:
+            # sort on state, we don't want that
+            return None, None
+        return col, attrname
+
+
+class RelativeDateColRenderer(tableview.EntityTableColRenderer):
+
+    def render_cell(self, w, rownum):
+        value = datetime.now() - getattr(self.entity(rownum), self.colid)
+        w(self._cw.printable_value('Interval', value))
+
+
+class ProjectTicketsTable(tableview.EntityTableView):
+    __regid__ = 'tracker.tickets.table'
+    __select__ = is_instance('Ticket')
+    columns = ['ticket', 'type', 'priority', 'in_state', 'done_in',
+               'creation_date', 'modification_date', 'created_by']
+    column_renderers = {
+        'ticket': tableview.MainEntityColRenderer(),
+        'creation_date': RelativeDateColRenderer(header=_('created')),
+        'modification_date': RelativeDateColRenderer(header=_('modified')),
+        'created_by': tableview.RelatedEntityColRenderer(
+                getrelated=lambda x: x.creator),
+        'in_state': tableview.EntityTableColRenderer(
+                renderfunc=lambda w,x: w(x.cw_adapt_to('IWorkflowable').printable_state)),
+        'done_in': tableview.RelatedEntityColRenderer(
+                getrelated=lambda x: x.done_in and x.done_in[0] or None),
+        }
+    layout_args = {
+        'display_filter': 'top',
+        'add_view_actions': True,
+        }
 
 
 # contextual components ########################################################
@@ -109,8 +178,7 @@ class ProjectTreeComponent(component.EntityCtxComponent):
     def render_body(self, w):
         rset = self.entity.cw_adapt_to('ITree').children(entities=False)
         treeid = 'project_tree_%s' % self.entity.eid
-        self.view('treeview', rset=rset, treeid=treeid,
-                  initial_thru_ajax=True, w=w)
+        self.wview('treeview', rset=rset, treeid=treeid, initial_thru_ajax=True)
 
 
 # secondary views ##############################################################
