@@ -10,7 +10,6 @@ _ = unicode
 from logilab.mtconverter import xml_escape
 
 from cubicweb.view import EntityView, EntityAdapter
-from cubicweb.schema import display_name
 from cubicweb.selectors import (objectify_selector, is_instance, multi_lines_rset,
                                 score_entity)
 from cubicweb import tags, uilib
@@ -23,13 +22,14 @@ _pvs.tag_attribute(('Ticket', 'title'), 'hidden')
 _pvs.tag_attribute(('Ticket', 'description'), 'attributes')
 _pvs.tag_subject_of(('Ticket', 'concerns', '*'), 'hidden')
 _pvs.tag_subject_of(('Ticket', 'done_in', '*'), 'attributes')
-_pvs.tag_subject_of(('Ticket', 'appeared_in', '*'), 'sideboxes')
+_pvs.tag_subject_of(('Ticket', 'appeared_in', '*'), 'attributes')
 _pvs.tag_subject_of(('Ticket', 'depends_on', '*'), 'sideboxes')
 _pvs.tag_object_of(('*', 'depends_on', 'Ticket'), 'sideboxes')
 
 _pvdc = uicfg.primaryview_display_ctrl
 _pvdc.tag_attribute(('Ticket', 'description'), {'showlabel': False})
 
+
 # primary view and tabs ########################################################
 
 class TicketPrimaryView(primary.PrimaryView):
