@@ -1,7 +1,7 @@
 """views for Version entities
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -12,14 +12,16 @@ from datetime import date
 from logilab.mtconverter import xml_escape
 
 from cubicweb import tags
-from cubicweb.selectors import (objectify_selector, is_instance, score_entity,
-                                match_search_state, one_line_rset)
-from cubicweb.view import StartupView, EntityView, EntityAdapter
+from cubicweb.schema import display_name
+from cubicweb.selectors import is_instance, score_entity
+from cubicweb.view import StartupView, EntityAdapter
 from cubicweb.web import uicfg, component, action
-from cubicweb.web.views import (primary, baseviews, tabs, xmlrss, navigation,
-                                iprogress, ibreadcrumbs)
+from cubicweb.web.views import (baseviews, tabs, tableview,
+                                xmlrss, navigation, ibreadcrumbs)
+
+from cubes.iprogress import views as iprogress
+from cubes.tracker.views import fixed_orderby_rql, project
 
-from cubes.tracker.entities import attr_tuple
 
 _pvs = uicfg.primaryview_section
 # in their own tabs
@@ -44,7 +46,8 @@ _pvdc.tag_attribute(('Version', 'description'), {'showlabel': False})
 
 class VersionPrimaryView(tabs.TabbedPrimaryView):
     __select__ = is_instance('Version')
-    tabs = tabs.TabbedPrimaryView.tabs + [_('tracker.version.defects_tab')]
+    tabs = tabs.TabbedPrimaryView.tabs + [_('tracker.version.defects_tab'),
+                                          'activitystream']
 
     def render_entity_title(self, entity):
         self._cw.add_css('cubes.tracker.css')
@@ -65,29 +68,46 @@ class VersionPrimaryTab(tabs.PrimaryTab):
             vid = len(entity.conflicts) > 1 and 'list' or 'outofcontext'
             self.wview(vid, entity.related('conflicts'))
             self.w(u'</ul></div>')
-        rset = self._cw.execute(*attr_tuple(entity, 'tickets_rql'))
+        rset = self._cw.execute(self.tickets_rql(), {'x': entity.eid})
         if rset:
-            nbcol = entity.tickets_rql_nb_displayed_cols
-            self._cw.view('table', rset, subvid='incontext',
-                          displaycols=range(nbcol), displayfilter=1,
-                          displayactions=1, w=self.w)
+            self.wview('tracker.version.tickets-table', rset)
         else:
-            self.w(u'<p>%s</p>') % self._cw._('There is no ticket in this version.')
+            self.w(u'<p>%s</p>' % self._cw._('There is no ticket in this version.'))
         super(VersionPrimaryTab, self).render_entity_relations(entity)
 
+    SORT_DEFS = (('in_state', 'S'), ('type', 'TT'), ('priority', 'TP'))
+    TICKETS_RELATION = 'done_in'
 
-class VersionDefectsTab(EntityView):
+    def tickets_rql(self):
+        # prefetch everything we can for optimization
+        return ('Any T,TTI,TT,TP,TD,TDF,TCD,TMD,S,SN %s WHERE '
+                'T title TTI, T type TT, T priority TP, '
+                'T description TD, T description_format TDF, '
+                'T creation_date TCD, T modification_date TMD, '
+                'T in_state S, S name SN, '
+                'T %s V, V eid %%(x)s'
+                % (fixed_orderby_rql(self.SORT_DEFS), self.TICKETS_RELATION))
+
+
+class VersionDefectsTab(VersionPrimaryTab):
     __regid__ = 'tracker.version.defects_tab'
     __select__ = (is_instance('Version')
                   & score_entity(lambda x: x.is_published()))
+    TICKETS_RELATION = 'appeared_in'
 
-    def cell_call(self, row, col):
-        entity = self.cw_rset.get_entity(row, col)
-        rset = self._cw.execute(*attr_tuple(entity, 'defects_rql'))
-        nbcol = entity.defects_rql_nb_displayed_cols
-        self._cw.view('table', rset, 'noresult', subvid='incontext',
-                      displaycols=range(nbcol), displayfilter=1,
-                      displayactions=1, w=self.w)
+    def entity_call(self, entity):
+        rset = self._cw.execute(self.tickets_rql(), {'x': entity.eid})
+        if rset:
+            self.wview('tracker.version.tickets-table', rset)
+        else:
+            self.w(u'<p>%s</p>' % self._cw._('No bugs reported for this version.'))
+
+
+class VersionTicketsTable(project.ProjectTicketsTable):
+    __regid__ = 'tracker.version.tickets-table'
+    columns = project.ProjectTicketsTable.columns[:]
+    columns.remove('done_in')
+    columns.remove('created_by')
 
 
 # ui adapters ##################################################################
@@ -200,33 +220,30 @@ class VersionOutOfContextView(baseviews.OutOfContextView):
 
 # other views ##################################################################
 
+def depends_on_cell(w, entity):
+    vrset = entity.depends_on_rset()
+    if vrset: # may be None
+        vid = len(vrset) > 1 and 'list' or 'outofcontext'
+        entity._cw.view(vid, vrset, 'null', w=w)
+    else:
+        w(u'&#160;')
+
 class VersionProgressTableView(iprogress.ProgressTableView):
     __select__ = is_instance('Version')
 
     title = _('version progression')
 
-    columns = (_('project'), _('milestone'), _('state'), _('planned_start'),
-               _('planned_delivery'), _('depends_on'), _('todo_by'))
+    columns = list(iprogress.ProgressTableView.columns)
+    columns.insert(columns.index('eta_date'), 'starting_date')
+    columns.append(_('depends_on'))
 
-    def build_depends_on_cell(self, entity):
-        vrset = entity.depends_on_rset()
-        if vrset: # may be None
-            vid = len(vrset) > 1 and 'list' or 'outofcontext'
-            return self._cw.view(vid, vrset, 'null')
-        return u''
-
-    def build_planned_start_cell(self, entity):
-        """``starting_date`` column cell renderer"""
-        if entity.starting_date:
-            return self._cw.format_date(entity.starting_date)
-        return u''
-
-    def build_planned_delivery_cell(self, entity):
-        """``initial_prevision_date`` column cell renderer"""
-        imilestone = entity.cw_adapt_to('IMileStone')
-        if imilestone.finished():
-            return self._cw.format_date(imilestone.completion_date())
-        return self._cw.format_date(imilestone.initial_prevision_date())
+    column_renderers = iprogress.ProgressTableView.column_renderers.copy()
+    column_renderers['eta_date'] = column_renderers['eta_date'].copy()
+    column_renderers['eta_date'].header = _('planned delivery')
+    column_renderers['depends_on'] = tableview.EntityTableColRenderer(
+        renderfunc=depends_on_cell)
+    column_renderers['starting_date'] = tableview.EntityTableColRenderer(
+        header=_('planned start'))
 
 
 class VersionsInfoView(StartupView):
